Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(510)

Unified Diff: third_party/WebKit/Source/core/input/PointerEventManager.cpp

Issue 1968653005: Set width=height=1 of mouse like pointer events (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/input/PointerEventManager.cpp
diff --git a/third_party/WebKit/Source/core/input/PointerEventManager.cpp b/third_party/WebKit/Source/core/input/PointerEventManager.cpp
index 06edf601103548efdd3f47e870a52307257a69ac..894e85ec67504549207a058f4a7f5ad1cfe27ae2 100644
--- a/third_party/WebKit/Source/core/input/PointerEventManager.cpp
+++ b/third_party/WebKit/Source/core/input/PointerEventManager.cpp
@@ -165,16 +165,16 @@ EventTarget* PointerEventManager::getEffectiveTargetForPointerEvent(
return target;
}
-void PointerEventManager::sendMouseAndPossiblyPointerNodeTransitionEvents(
+void PointerEventManager::sendMouseAndPossiblyPointerBoundaryEvents(
Node* exitedNode,
Node* enteredNode,
const PlatformMouseEvent& mouseEvent,
AbstractView* view,
bool isFrameBoundaryTransition)
{
// Pointer event type does not matter as it will be overridden in the sendNodeTransitionEvents
PointerEvent* pointerEvent =
- m_pointerEventFactory.create(EventTypeNames::mouseout, mouseEvent,
+ m_pointerEventFactory.create(EventTypeNames::mousedown, mouseEvent,
nullptr, view);
// TODO(crbug/545647): This state should reset with pointercancel too.
@@ -192,7 +192,7 @@ void PointerEventManager::sendMouseAndPossiblyPointerNodeTransitionEvents(
exitedNode, mouseEvent, true, isFrameBoundaryTransition);
}
-void PointerEventManager::sendNodeTransitionEvents(
+void PointerEventManager::sendBoundaryEvents(
EventTarget* exitedTarget,
EventTarget* enteredTarget,
PointerEvent* pointerEvent,
@@ -325,12 +325,12 @@ void PointerEventManager::setNodeUnderPointer(
EventTargetAttributes(target, false));
}
if (sendEvent)
- sendNodeTransitionEvents(node.target, target, pointerEvent);
+ sendBoundaryEvents(node.target, target, pointerEvent);
} else if (target) {
m_nodeUnderPointer.add(pointerEvent->pointerId(),
EventTargetAttributes(target, false));
if (sendEvent)
- sendNodeTransitionEvents(nullptr, target, pointerEvent);
+ sendBoundaryEvents(nullptr, target, pointerEvent);
}
}
@@ -578,7 +578,7 @@ void PointerEventManager::processCaptureAndPositionOfPointerEvent(
}
if (sendMouseEvent && !isCaptureChanged) {
// lastNodeUnderMouse is needed here because it is still stored in EventHandler.
- sendNodeTransitionEvents(lastNodeUnderMouse, hitTestTarget,
+ sendBoundaryEvents(lastNodeUnderMouse, hitTestTarget,
pointerEvent, mouseEvent, true);
}
}
@@ -609,10 +609,10 @@ bool PointerEventManager::processPendingPointerCapture(
if (sendMouseEvent) {
// Send pointer event transitions as the line after this if
// block sends the mouse events
- sendNodeTransitionEvents(nodeUnderPointerAtt.target, nullptr,
+ sendBoundaryEvents(nodeUnderPointerAtt.target, nullptr,
pointerEvent);
}
- sendNodeTransitionEvents(nodeUnderPointerAtt.target, nullptr,
+ sendBoundaryEvents(nodeUnderPointerAtt.target, nullptr,
pointerEvent, mouseEvent, sendMouseEvent);
}
if (pointerCaptureTarget) {
@@ -630,7 +630,7 @@ bool PointerEventManager::processPendingPointerCapture(
}
// Set pointerCaptureTarget from pendingPointerCaptureTarget. This does
// affect the behavior of sendNodeTransitionEvents function. So the
// ordering of the surrounding blocks of code for sending transition events
// are important.
if (pendingPointerCaptureTarget)
@@ -649,9 +649,9 @@ bool PointerEventManager::processPendingPointerCapture(
if (sendMouseEvent) {
// Send pointer event transitions as the line after this if
// block sends the mouse events
- sendNodeTransitionEvents(nullptr, hitTestTarget, pointerEvent);
+ sendBoundaryEvents(nullptr, hitTestTarget, pointerEvent);
}
- sendNodeTransitionEvents(nullptr, hitTestTarget, pointerEvent,
+ sendBoundaryEvents(nullptr, hitTestTarget, pointerEvent,
mouseEvent, sendMouseEvent);
}
}
@@ -165,16 +165,16 @@ EventTarget* PointerEventManager::getEffectiveTargetForPointerEvent(
bool isFrameBoundaryTransition)
{
- // Pointer event type does not matter as it will be overridden in the sendNodeTransitionEvents
+ // Pointer event type does not matter as it will be overridden in the sendBoundaryEvents
PointerEvent* pointerEvent =
@@ -630,7 +630,7 @@ bool PointerEventManager::processPendingPointerCapture(
}
// Set pointerCaptureTarget from pendingPointerCaptureTarget. This does
- // affect the behavior of sendNodeTransitionEvents function. So the
+ // affect the behavior of sendBoundaryEvents function. So the
// ordering of the surrounding blocks of code for sending transition events
// are important.

Powered by Google App Engine
This is Rietveld 408576698